pub unsafe fn register_disk_handler(handler: impl FatfsDiskHandler + 'static)Expand description
Register user-provided fatfs functions. All fatfs functions will panic if this is not called.
pub unsafe fn register_disk_handler(handler: impl FatfsDiskHandler + 'static)Register user-provided fatfs functions. All fatfs functions will panic if this is not called.